@@ -1489,22 +1489,22 @@ lib_kbd_files = Split('''
 
 
 lib_templates_files = Split('''
-    IEEEtran.lyx
-    README.new_templates
     aa.lyx
     aastex.lyx
+    ACM-sigplan.lyx
     agu_article.lyx
     apa.lyx
     beamer-conference-ornate-20min.lyx
     de_beamer-conference-ornate-20min.lyx
     dinbrief.lyx
     docbook_article.lyx
-    elsart.lyx
+    elsarticle.lyx
     fr_beamer-conference-ornate-20min.lyx
     g-brief-de.lyx
     g-brief-en.lyx
     g-brief2.lyx
     hollywood.lyx
+    IEEEtran.lyx
     ijmpc.lyx
     ijmpd.lyx
     iop-article.lyx
@@ -1513,6 +1513,7 @@ lib_templates_files = Split('''
     koma-letter2.lyx
     latex8.lyx
     letter.lyx
+    README.new_templates
     revtex.lyx
     revtex4.lyx
     slides.lyx
@@ -2277,6 +2278,11 @@ lib_doc_extra_files = Split('''
 ''')
 
 
+lib_doc_ca_files = Split('''
+    Intro.lyx
+''')
+
+
 lib_doc_cs_files = Split('''
     Tutorial.lyx
 ''')
@@ -2479,13 +2485,22 @@ lib_doc_sv_files = Split('''
 ''')
 
 
+lib_doc_uk_files = Split('''
+    Intro.lyx
+''')
+
+
+lib_doc_uk_clipart_files = Split('''
+    FootnoteQT4.png
+''')
+
+
 lib_examples_files = Split('''
     CV-image.eps
     CV-image.png
     Foils.lyx
     ItemizeBullets.lyx
     Literate.lyx
-    Minipage.lyx
     aa_sample.lyx
     aas_sample.lyx
     addressExample.adr
@@ -2516,7 +2531,6 @@ lib_examples_files = Split('''
     iecc12.fen
     landslide.lyx
     listerrors.lyx
-    listings.lyx
     modernCV.lyx
     multicol.lyx
     noweb2lyx.lyx
@@ -2531,6 +2545,8 @@ lib_examples_files = Split('''
 
 
 lib_examples_ca_files = Split('''
+    ItemizeBullets.lyx
+    mathed.lyx
     splash.lyx
 ''')
 
@@ -2549,7 +2565,6 @@ lib_examples_de_files = Split('''
     Dezimal.lyx
     ItemizeBullets.lyx
     Lebenslauf.lyx
-    Minipage.lyx
     beispiel_gelyxt.lyx
     beispiel_roh.lyx
     multicol.lyx
@@ -2569,7 +2584,6 @@ lib_examples_fr_files = Split('''
     AlignementDecimal.lyx
     Foils.lyx
     ListesPuces.lyx
-    Minipage.lyx
     exemple_brut.lyx
     exemple_lyxifie.lyx
     multicol.lyx
@@ -2679,6 +2693,7 @@ lib_lyx2lyx_files = Split('''
     lyx_1_3.py
     lyx_1_4.py
     lyx_1_5.py
+    lyx_1_6.py
     parser_tools.py
     profiling.py
     test_parser_tools.py
@@ -2693,7 +2708,6 @@ lib_lyx2lyx_extra_files = Split('''
 
 
 lib_layouts_files = Split('''
-    IEEEtran.layout
     aa.layout
     aapaper.layout
     aastex.layout
@@ -2721,6 +2735,7 @@ lib_layouts_files = Split('''
     dtk.layout
     egs.layout
     elsart.layout
+    elsarticle.layout
     entcs.layout
     europecv.layout
     extarticle.layout
@@ -2734,6 +2749,7 @@ lib_layouts_files = Split('''
     heb-article.layout
     heb-letter.layout
     hollywood.layout
+    IEEEtran.layout
     ijmpc.layout
     ijmpd.layout
     iopart.layout
@@ -2767,10 +2783,13 @@ lib_layouts_files = Split('''
     scrreprt.layout
     seminar.layout
     siamltex.layout
+    sigplanconf.layout
     simplecv.layout
+    singlecol.layout
     slides.layout
     spie.layout
     svglobal.layout
+    svglobal3.layout
     svjog.layout
     svprobth.layout
 ''')
