@@ -460,34 +460,30 @@ void BufferView::setCursorFromScrollbar()
 	int const height = 2 * defaultRowHeight();
 	int const first = height;
 	int const last = height_ - height;
-	Cursor & cur = cursor_;
-
-	bv_funcs::CurStatus st = bv_funcs::status(this, cur);
-
-	switch (st) {
+	int newy = 0;
+	Cursor const & oldcur = cursor_;
+	
+	switch (bv_funcs::status(this, oldcur)) {
 	case bv_funcs::CUR_ABOVE:
-		// We reset the cursor because bv_funcs::status() does not
-		// work when the cursor is within mathed.
-		cur.reset(buffer_->inset());
-		t.setCursorFromCoordinates(cur, 0, first);
-		cur.clearSelection();
+		newy = first;
 		break;
 	case bv_funcs::CUR_BELOW:
-		// We reset the cursor because bv_funcs::status() does not
-		// work when the cursor is within mathed.
-		cur.reset(buffer_->inset());
-		t.setCursorFromCoordinates(cur, 0, last);
-		cur.clearSelection();
+		newy = last;
 		break;
 	case bv_funcs::CUR_INSIDE:
-		int const y = bv_funcs::getPos(*this, cur, cur.boundary()).y_;
-		int const newy = min(last, max(y, first));
-		if (y != newy) {
-			cur.reset(buffer_->inset());
-			t.setCursorFromCoordinates(cur, 0, newy);
-		}
+		int const y = bv_funcs::getPos(*this, 
+					       oldcur, oldcur.boundary()).y_;
+		newy = min(last, max(y, first));
+		if (y == newy)
+			return;
 	}
-}
+	// We reset the cursor because cursorStatus() does not
+	// work when the cursor is within mathed.
+	Cursor cur(*this);
+	cur.reset(buffer_->inset());
+	t.setCursorFromCoordinates(cur, 0, newy);
+	mouseSetCursor(cur);
+ }
 
 
 Change const BufferView::getCurrentChange() const
@@ -1274,6 +1270,27 @@ void BufferView::setCursorFromRow(int row)
 }
 
 
+bool BufferView::setCursorFromInset(Inset const * inset)
+{
+	// are we already there?
+	if (cursor().nextInset() == inset)
+		return true;
+
+	// Inset is not at cursor position. Find it in the document.
+	Cursor cur(*this);
+	cur.reset(buffer()->inset());
+	do 
+		cur.forwardInset();
+	while (cur && cur.nextInset() != inset);
+
+	if (cur) {
+		setCursor(cur);
+		return true;
+	}
+	return false;
+}
+
+
 void BufferView::gotoLabel(docstring const & label)
 {
 	for (InsetIterator it = inset_iterator_begin(buffer_->inset()); it; ++it) {
