@@ -34,6 +34,7 @@
 #include "Paragraph.h"
 #include "paragraph_funcs.h"
 #include "ParIterator.h"
+#include "Undo.h"
 
 #include "insets/InsetTabular.h"
 #include "insets/InsetText.h"
@@ -1302,6 +1303,8 @@ void Cursor::handleFont(string const & font)
 		safe = cap::grabAndEraseSelection(*this);
 	}
 
+	recordUndoInset(*this);
+
 	if (lastpos() != 0) {
 		// something left in the cell
 		if (pos() == 0) {
@@ -1321,8 +1324,9 @@ void Cursor::handleFont(string const & font)
 		}
 	} else {
 		// nothing left in the cell
-		pullArg();
+		popLeft();
 		plainErase();
+		resetAnchor();
 	}
 	insert(safe);
 }
@@ -1346,6 +1350,21 @@ docstring Cursor::selectionAsString(bool label) const
 		return docstring();
 
 	if (inTexted()) {
+		idx_type const startidx = selBegin().idx();
+		idx_type const endidx = selEnd().idx();
+		if (startidx != endidx) {
+			// multicell selection
+#if 0
+// FIXME: we do not have table->asString, thus we have to return docstring() here.
+			InsetTabular * table = static_cast<InsetTabular*>(&inset());
+			BOOST_ASSERT(table);
+			if (!table)
+				return docstring();
+			table->asString(startidx, endidx);
+#endif
+			return docstring();
+		}
+
 		Buffer const & buffer = *bv().buffer();
 		ParagraphList const & pars = text()->paragraphs();
 
