@@ -14,7 +14,10 @@
 #ifndef LATEX_H
 #define LATEX_H
 
-#include "outputparams.h"
+#include "OutputParams.h"
+
+#include "support/docstring.h"
+#include "support/FileName.h"
 
 #include <boost/utility.hpp>
 #include <boost/signal.hpp>
@@ -22,6 +25,9 @@
 #include <vector>
 #include <set>
 
+
+namespace lyx {
+
 class DepTable;
 
 ///
@@ -33,16 +39,16 @@ private:
 		///
 		Error () : error_in_line(0) {}
 		///
-		Error(int line, std::string const & desc, std::string const & text)
+		Error(int line, docstring const & desc, docstring const & text)
 			: error_in_line(line),
 			  error_desc(desc),
 			  error_text(text) {}
 		/// what line in the TeX file the error occured in
 		int error_in_line;
 		/// The kind of error
-		std::string error_desc;
+		docstring error_desc;
 		/// The line/cmd that caused the error.
-		std::string error_text;
+		docstring error_text;
 	};
 public:
 	///
@@ -52,8 +58,8 @@ public:
 	///
 	Errors::const_iterator end() const { return errors.end(); }
 	///
-	void insertError(int line, std::string const & error_desc,
-			 std::string const & error_text);
+	void insertError(int line, docstring const & error_desc,
+			 docstring const & error_text);
 private:
 	///
 	Errors errors;
@@ -65,7 +71,7 @@ public:
 	///
 	Aux_Info() {}
 	///
-	std::string aux_file;
+	support::FileName aux_file;
 	///
 	std::set<std::string> citations;
 	///
@@ -80,7 +86,13 @@ bool operator==(Aux_Info const &, Aux_Info const &);
 bool operator!=(Aux_Info const &, Aux_Info const &);
 
 
-///
+/**
+ * Class to run the LaTeX compiler and needed auxiliary programs.
+ * The main .tex file must be in the current directory. The current directory
+ * must not change as long as an object of this class lives.
+ * This is required by the LaTeX compiler, and we also make use of it by
+ * various support::makeAbsPath() calls.
+ */
 class LaTeX : boost::noncopyable {
 public:
 	/** Return values from scanLogFile() and run() (to come)
@@ -126,7 +138,7 @@ public:
 	};
 
 	/// This signal emits an informative message
-	boost::signal<void(std::string)> message;
+	boost::signal<void(docstring)> message;
 
 
 	/**
@@ -134,7 +146,7 @@ public:
 	   path = name of the files original path.
 	*/
 	LaTeX(std::string const & cmd, OutputParams const &,
-	      std::string const & file, std::string const & path);
+	      support::FileName const & file);
 
 	/// runs LaTeX several times
 	int run(TeXErrors &);
@@ -150,22 +162,27 @@ private:
 	int startscript();
 
 	/// The dependency file.
-	std::string depfile;
+	support::FileName depfile;
 
 	///
 	void deplog(DepTable & head);
 
 	///
-	bool runMakeIndex(std::string const &, OutputParams const &);
+	bool runMakeIndex(std::string const &, OutputParams const &,
+			  std::string const & = std::string());
 
 	///
-	std::vector<Aux_Info> const scanAuxFiles(std::string const &);
+	bool runMakeIndexNomencl(support::FileName const &, OutputParams const &,
+				 std::string const &, std::string const &);
 
 	///
-	Aux_Info const scanAuxFile(std::string const &);
+	std::vector<Aux_Info> const scanAuxFiles(support::FileName const &);
 
 	///
-	void scanAuxFile(std::string const &, Aux_Info &);
+	Aux_Info const scanAuxFile(support::FileName const &);
+
+	///
+	void scanAuxFile(support::FileName const &, Aux_Info &);
 
 	///
 	void updateBibtexDependencies(DepTable &,
@@ -181,19 +198,19 @@ private:
 	std::string cmd;
 
 	///
-	std::string file;
-
-	///
-	std::string path;
+	support::FileName file;
 
 	/// used by scanLogFile
 	int num_errors;
 
 	/// The name of the final output file.
-	std::string output_file;
+	support::FileName output_file;
 
 	///
 	OutputParams runparams;
 };
 
+
+} // namespace lyx
+
 #endif
