@@ -444,7 +444,8 @@ char const * simplefeatures[] = {
 	"mathrsfs",
 	"ascii",
 	"url",
-	"bm"
+	"bm",
+	"amscd"
 };
 
 int const nb_simplefeatures = sizeof(simplefeatures) / sizeof(char const *);
@@ -473,10 +474,11 @@ string const LaTeXFeatures::getPackages() const
 	//
 
 	// esint is preferred for esintoramsmath
-	if ((mustProvide("amsmath") &&
-	     params_.use_amsmath != BufferParams::package_off) ||
-	    (mustProvide("esintoramsmath") &&
-	     params_.use_esint == BufferParams::package_off)) {
+	if ((mustProvide("amsmath")
+	     && params_.use_amsmath != BufferParams::package_off)
+	    || (mustProvide("esintoramsmath")
+	        && params_.use_esint == BufferParams::package_off
+	        && params_.use_amsmath != BufferParams::package_off)) {
 		packages << "\\usepackage{amsmath}\n";
 	} else if (mustProvide("amsbsy")) {
 		// amsbsy is already provided by amsmath
@@ -499,7 +501,8 @@ string const LaTeXFeatures::getPackages() const
 	if (mustProvide("color") || mustProvide("xcolor")) {
 		string const package =
 			(mustProvide("xcolor") ? "xcolor" : "color");
-		if (params_.graphicsDriver == "default")
+		if (params_.graphicsDriver == "default"
+		    || params_.graphicsDriver == "none")
 			packages << "\\usepackage{" << package << "}\n";
 		else
 			packages << "\\usepackage["
@@ -586,7 +589,10 @@ string const LaTeXFeatures::getPackages() const
 		packages << "\\usepackage{esint}\n";
 
 	// natbib.sty
-	if (mustProvide("natbib")) {
+	// Some classes load natbib themselves, but still allow (or even require)
+	// plain numeric citations (ReVTeX is such a case, see bug 5182).
+	// This special case is indicated by the "natbib-internal" key.
+	if (mustProvide("natbib") && !tclass.provides("natbib-internal")) {
 		packages << "\\usepackage[";
 		if (params_.getEngine() == biblio::ENGINE_NATBIB_NUMERICAL) {
 			packages << "numbers";
