@@ -1645,9 +1645,14 @@ void LyXFunc::dispatch(FuncRequest const & cmd)
 			string const name = cmd.getArg(0);
 			Inset * inset = lyx_view_->getDialogs().getOpenInset(name);
 			if (inset) {
-				FuncRequest fr(LFUN_INSET_MODIFY, argument);
+				// put cursor in front of inset. 
+				if (!view()->setCursorFromInset(inset))
+					BOOST_ASSERT(false);
+				recordUndo(view()->cursor());
+ 				FuncRequest fr(LFUN_INSET_MODIFY, argument);
 				inset->dispatch(view()->cursor(), fr);
 			} else {
+				recordUndo(view()->cursor());
 				FuncRequest fr(LFUN_INSET_INSERT, argument);
 				dispatch(fr);
 			}
@@ -2037,9 +2042,14 @@ void LyXFunc::open(string const & fname)
 			make_pair(_("Documents|#o#O"), from_utf8(lyxrc.document_path)),
 			make_pair(_("Examples|#E#e"), from_utf8(addPath(package().system_support().absFilename(), "examples"))));
 
+		docstring filter = _("LyX Documents (*.lyx);;");
+		filter += _("LyX-1.3.x Documents (*.lyx13);;");
+		filter += _("LyX-1.4.x Documents (*.lyx14);;");
+		filter += _("LyX-1.5.x Documents (*.lyx15)");
+
 		FileDialog::Result result =
 			fileDlg.open(from_utf8(initpath),
-				     FileFilterList(_("LyX Documents (*.lyx)")),
+				     FileFilterList(filter),
 				     docstring());
 
 		if (result.first == FileDialog::Later)
@@ -2291,6 +2301,7 @@ void actOnUpdatedPrefs(LyXRC const & lyxrc_orig, LyXRC const & lyxrc_new)
 	case LyXRC::RC_FONT_ENCODING:
 	case LyXRC::RC_FORMAT:
 	case LyXRC::RC_INDEX_COMMAND:
+	case LyXRC::RC_NOMENCL_COMMAND:
 	case LyXRC::RC_INPUT:
 	case LyXRC::RC_KBMAP:
 	case LyXRC::RC_KBMAP_PRIMARY:
