@@ -29,6 +29,7 @@
 #include "BufferView.h"
 #include "bufferview_funcs.h"
 #include "Bullet.h"
+#include "Color.h"
 #include "CoordCache.h"
 #include "Cursor.h"
 #include "CutAndPaste.h"
@@ -38,7 +39,7 @@
 #include "FuncRequest.h"
 #include "gettext.h"
 #include "Language.h"
-#include "Color.h"
+#include "Lexer.h"
 #include "LyXFunc.h"
 #include "LyXRC.h"
 #include "Row.h"
@@ -72,7 +73,7 @@ using std::ostringstream;
 using std::string;
 using std::max;
 using std::min;
-
+using std::istringstream;
 
 Text::Text()
 	: current_font(Font::ALL_INHERIT),
@@ -161,15 +162,9 @@ Font Text::getFont(Buffer const & buffer, Paragraph const & par,
 		Font f = par.getFontSettings(params, pos);
 		if (!isMainText(buffer))
 			applyOuterFont(buffer, f);
-		Font lf;
-		Font rlf;
-		if (layout->labeltype == LABEL_MANUAL && pos < body_pos) {
-			lf = layout->labelfont;
-			rlf = layout->reslabelfont;
-		} else {
-			lf = layout->font;
-			rlf = layout->resfont;
-		}
+		bool lab = layout->labeltype == LABEL_MANUAL && pos < body_pos;
+		Font const & lf = lab ? layout->labelfont : layout->font;
+		Font rlf = lab ? layout->reslabelfont : layout->resfont;
 		// In case the default family has been customized
 		if (lf.family() == Font::INHERIT_FAMILY)
 			rlf.setFamily(params.getFont().family());
@@ -177,11 +172,8 @@ Font Text::getFont(Buffer const & buffer, Paragraph const & par,
 	}
 
 	// The uncommon case need not be optimized as much
-	Font layoutfont;
-	if (pos < body_pos)
-		layoutfont = layout->labelfont;
-	else
-		layoutfont = layout->font;
+	Font const & layoutfont = pos < body_pos ?
+		layout->labelfont : layout->font;
 
 	Font font = par.getFontSettings(params, pos);
 	font.realize(layoutfont);
@@ -633,9 +625,7 @@ docstring Text::getStringToIndex(Cursor const & cur)
 }
 
 
-void Text::setParagraph(Cursor & cur,
-			   Spacing const & spacing, LyXAlignment align,
-			   docstring const & labelwidthstring, bool noindent)
+void Text::setParagraphs(Cursor & cur, docstring arg, bool merge) 
 {
 	BOOST_ASSERT(cur.text());
 	// make sure that the depth behind the selection are restored, too
@@ -645,22 +635,33 @@ void Text::setParagraph(Cursor & cur,
 	for (pit_type pit = cur.selBegin().pit(), end = cur.selEnd().pit();
 	     pit <= end; ++pit) {
 		Paragraph & par = pars_[pit];
-		ParagraphParameters & params = par.params();
-		params.spacing(spacing);
-
-		// does the layout allow the new alignment?
-		//FIXME The reason we need the first check is because
-		//LYX_ALIGN_LAYOUT isn't required to be possible. It
-		//should be...and will be.
-		if ((align == LYX_ALIGN_LAYOUT) ||
-		    (align & par.layout()->alignpossible))
-		    	params.align(align);
-		par.setLabelWidthString(labelwidthstring);
-		params.noindent(noindent);
+		ParagraphParameters params = par.params();
+		params.read(to_utf8(arg), merge);
+		Layout const & layout = *(par.layout());
+		par.params().apply(params, layout);
 	}
 }
 
 
+//FIXME This is a little redundant now, but it's probably worth keeping,
+//especially if we're going to go away from using serialization internally
+//quite so much.
+void Text::setParagraphs(Cursor & cur, ParagraphParameters const & p) 
+{
+	BOOST_ASSERT(cur.text());
+	// make sure that the depth behind the selection are restored, too
+	pit_type undopit = undoSpan(cur.selEnd().pit());
+	recUndo(cur, cur.selBegin().pit(), undopit - 1);
+
+	for (pit_type pit = cur.selBegin().pit(), end = cur.selEnd().pit();
+	     pit <= end; ++pit) {
+		Paragraph & par = pars_[pit];
+		Layout const & layout = *(par.layout());
+		par.params().apply(p, layout);
+	}	
+}
+
+
 // this really should just insert the inset and not move the cursor.
 void Text::insertInset(Cursor & cur, Inset * inset)
 {
@@ -1149,7 +1150,8 @@ bool Text::deleteEmptyParagraphMechanism(Cursor & cur,
 		    && old.pos() < oldpar.size()
 		    && oldpar.isLineSeparator(old.pos())
 		    && oldpar.isLineSeparator(old.pos() - 1)
-		    && !oldpar.isDeleted(old.pos() - 1)) {
+		    && !oldpar.isDeleted(old.pos() - 1)
+		    && !oldpar.isDeleted(old.pos())) {
 			oldpar.eraseChar(old.pos() - 1, cur.buffer().params().trackChanges);
 #ifdef WITH_WARNINGS
 #warning This will not work anymore when we have multiple views of the same buffer
@@ -1184,7 +1186,11 @@ bool Text::deleteEmptyParagraphMechanism(Cursor & cur,
 			   max(old.pit() - 1, pit_type(0)),
 			   min(old.pit() + 1, old.lastpit()));
 		ParagraphList & plist = old.text()->paragraphs();
+		bool const soa = oldpar.params().startOfAppendix();
 		plist.erase(boost::next(plist.begin(), old.pit()));
+		// do not lose start of appendix marker (bug 4212)
+		if (soa && old.pit() < plist.size())
+			plist[old.pit()].params().startOfAppendix(true);
 
 		// see #warning above
 		if (cur.depth() >= old.depth()) {
