@@ -16,14 +16,18 @@
 
 
 #include "Dialog.h"
+
+#include "support/docstring.h"
+
 #include <utility>
 #include <vector>
 
+namespace lyx {
+
 class InsetGraphics;
 class InsetGraphicsParams;
 class LyXView;
 
-namespace lyx {
 namespace frontend {
 
 /** A controller for Graphics dialogs.
@@ -46,7 +50,7 @@ public:
 	InsetGraphicsParams const & params() const { return *params_.get(); }
 
 	/// Browse for a file
-	std::string const browse(std::string const &) const;
+	docstring const browse(docstring const &) const;
 	/// Read the Bounding Box from a eps or ps-file
 	std::string const readBB(std::string const & file);
 	/// Control the bb
@@ -66,7 +70,7 @@ private:
 std::vector<std::string> const getBBUnits();
 
 /// The (tranlated) GUI std::string and it's LaTeX equivalent.
-typedef std::pair<std::string, std::string> RotationOriginPair;
+typedef std::pair<docstring, std::string> RotationOriginPair;
 ///
 std::vector<RotationOriginPair> getRotationOriginData();
 
