@@ -15,6 +15,8 @@
 
 #include "Dialog.h"
 
+#include "support/FileName.h"
+
 namespace lyx {
 namespace frontend {
 
@@ -37,7 +39,7 @@ public:
 	virtual bool isBufferDependent() const { return true; }
 
 	/// The title displayed by the dialog reflects the \c LOGTYPE
-	std::string const title() const;
+	docstring const title() const;
 	/// put the log file into the ostream
 	void getContents(std::ostream & ss) const;
 
@@ -51,7 +53,7 @@ private:
 	};
 
 	LOGTYPE type_;
-	std::string logfile_;
+	support::FileName logfile_;
 };
 
 } // namespace frontend
