@@ -661,6 +661,9 @@ TeXOnePar(Buffer const & buf,
 	if (boost::next(pit) == paragraphs.end() && !style->isEnvironment()) {
 		switch (open_encoding_) {
 			case CJK: {
+				// do nothing at the end of child documents
+				if (maintext && buf.getMasterBuffer() != &buf)
+					break;
 				// end of main text
 				if (maintext) {
 					os << '\n';
@@ -744,10 +747,13 @@ void latexParagraphs(Buffer const & buf,
 	}
 
 	bool const maintext = text.isMainText(buf);
+	bool const is_child = buf.getMasterBuffer() != &buf;
 
 	// Open a CJK environment at the beginning of the main buffer
 	// if the document's language is a CJK language
-	if (maintext && bparams.encoding().package() == Encoding::CJK) {
+	// (but not in child documents)
+	if (maintext && !is_child
+	    && bparams.encoding().package() == Encoding::CJK) {
 		os << "\\begin{CJK}{" << from_ascii(bparams.encoding().latexName())
 		<< "}{}%\n";
 		texrow.newline();
@@ -847,7 +853,7 @@ void latexParagraphs(Buffer const & buf,
 	}
 	// If the last paragraph is an environment, we'll have to close
 	// CJK at the very end to do proper nesting.
-	if (maintext && open_encoding_ == CJK) {
+	if (maintext && !is_child && open_encoding_ == CJK) {
 		os << "\\end{CJK}\n";
 		texrow.newline();
 		open_encoding_ = none;
@@ -864,7 +870,7 @@ void latexParagraphs(Buffer const & buf,
 pair<bool, int> switchEncoding(odocstream & os, BufferParams const & bparams,
 		   OutputParams const & runparams, Encoding const & newEnc)
 {
-	Encoding const oldEnc = *runparams.encoding;
+	Encoding const & oldEnc = *runparams.encoding;
 	bool moving_arg = runparams.moving_arg;
 	if ((bparams.inputenc != "auto" && bparams.inputenc != "default")
 		|| moving_arg)
